/*
** Module   : FontDetails.java
** Abstract : a container for a font, font metrics and related state
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 GES 20150427 Created initial version based on the inner class of the FontManager.
*/

package com.goldencode.p2j.ui.client;

/**
 * A container for a font, font metrics and related state.
 */
public class FontDetails<F>
{
   /** A unique descriptor describing the font name, size and attributes. */
   public String key;
   
   /** The font object instance. */
   public F font;
   
   /** Font style. */
   public FontStyle style;
   
   /** Point size for this font. */
   public int pointSize;
   
   /** The legacy width of this font; negative value if this was not configured. */
   public int legacyWidth = -1;
   
   /** The legacy max width of this font; negative value if this was not configured. */
   public int legacyMaxWidth = -1;

   /** The legacy height of this font; negative value if this was not configured. */
   public int legacyHeight = -1;
   
   /** Byte array with the custom font definition. */
   public byte[] fontDefinition;
   
   /** Flag indicating this is a fixed-size font. */
   public boolean fixedSize;
   
   /**
    * Create new font details.
    */
   public FontDetails()
   {
   }
   
   /**
    * Create new font details.
    * 
    * @param    font
    *           The font object instance.
    * @param    legacyWidth
    *           The legacy width of this font; negative value if this was not configured.
    * @param    legacyHeight
    *           The legacy height of this font; negative value if this was not configured.
    * @param    fontDefinition
    *           Byte array with the custom font definition.
    */
   public FontDetails(F font, int legacyWidth, int legacyHeight, byte[] fontDefinition)
   {
      this.font           = font;
      this.legacyWidth    = legacyWidth;
      this.legacyHeight   = legacyHeight;
      this.fontDefinition = fontDefinition;
   }
   
   /**
    * Return a new font details instance with the same copied state.
    *
    * @return   The copied instance.
    */
   public FontDetails<F> copy()
   {
      FontDetails<F> fd = new FontDetails<F>();
      
      fd.key            = this.key;      
      fd.font           = this.font;     
      fd.style          = this.style;    
      fd.pointSize      = this.pointSize;
      fd.legacyWidth    = this.legacyWidth;
      fd.legacyMaxWidth = this.legacyWidth;
      fd.legacyHeight   = this.legacyHeight;
      fd.fixedSize      = this.fixedSize;
      
      // normally we would make a copy of this array, but this is essentially a read-only
      // array of bytes and we don't want duplicates of that data
      fd.fontDefinition = this.fontDefinition;
      
      return fd;
   }
}
