/*
** Module   : ChuiClient.java
** Abstract : applet container for the ChuiSimulator class
**
** Copyright (c) 2011-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 GES 20110921 Created initial version.
** 002 MAG 20140508 Move common code to AbstractClient.
** 003 CA  20140805 Added ChUI specific client initialization.
** 004 GES 20150506 Modifications to match code moved from ChuiSimulator so that it could be
**                  shared for Swing and Web clients.
*/

package com.goldencode.p2j.ui.client.chui.driver.swing;

import java.util.logging.*;
import java.lang.reflect.*;
import javax.swing.*;

import com.goldencode.p2j.ui.client.driver.swing.*;
import com.goldencode.p2j.ui.client.chui.driver.*;
import com.goldencode.p2j.util.LogHelper;

/**
 * Provides the containing frame for the content pane when used as an application.
 */
@SuppressWarnings("serial")
public class ChuiClient
extends AbstractClient
{
   /** Logger. */
   private static final Logger LOG = LogHelper.getLogger(ChuiClient.class.getName());
   
   /** Frame title. */
   private static String title = "P2J ChUI Client";
   
   /** Simulator instance. */
   private ChuiSimulator sim = null;
   
   /**
    * Construct the new frame by instantiating the {@link ChuiSimulator} as
    * the content pane and initializing it using the given <code>options</code>.
    *
    * @param    options
    *           The configuration parameters for the content pane.
    */
   public ChuiClient(TerminalOptions options)
   {
      super(title);
      
      sim = new ChuiSimulator(this, this, options);
      
      init(sim.getContentPane(), false);
   }
   
   /**
    * Initialize the application frame by creating a new instance of this
    * class and of the content pane which is an instance of
    * {@link ChuiSimulator}.
    *
    * @param    options
    *           The configuration parameters for the content pane.
    *
    * @return   The simulator instance. It will only be <code>null</code> if a catastrophic
    *           failure has occurred.
    */
   public static ChuiSimulator load(final TerminalOptions options)
   {
      // lame hack because of Java flaw
      final ChuiClient[] client = new ChuiClient[1];
      
      try
      {
         // instantiate the application's main frame
         SwingUtilities.invokeAndWait(new Runnable()
         {
            public void run()
            {
               client[0] = new ChuiClient(options);
            }
         });
      }
      
      catch (InterruptedException | InvocationTargetException exc)
      {
         if (LOG.isLoggable(Level.SEVERE))
         {
            LOG.log(Level.SEVERE, "Could not load ChuiClient instance.", exc);
         }
         
         return null;
      }
      
      return client[0].sim;
   }

   /**
    * Initialize.
    * 
    * @param   pane
    *          Content pane.
    * @param   resizable
    *          Resizable attribute.
    */
   protected void init(JComponent pane, boolean resizable)
   {
      super.init(pane, resizable);

      forceResize();
   }
}
