/*
** Module   : WindowWorkSpace.java
** Abstract : window workspace widget
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 MAG 20141010 Created initial version.
** 002 CA  20141119 Refactored drawing code to enable multiple OS windows, for GUI support.  Misc
**                  changes/fixes related to drawing on multiple windows.
** 003 EVL 20141126 Content pane GUI fix.
** 004 EVL 20141127 Inserting this container into mouse source chain.
** 005 EVL 20141206 Fix for scrollbar not responding regression.
** 006 GES 20150425 Match class name change for GuiOptions to GuiConstants.
*/

package com.goldencode.p2j.ui.client.gui;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.chui.ThinClient;
import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.event.*;
import com.goldencode.p2j.ui.client.ScrollBar.Bars;
import com.goldencode.p2j.ui.client.gui.driver.*;
import com.goldencode.p2j.ui.client.widget.*;

/**
 * Window work area.  A scrollable container.
 */
public class WindowWorkSpace
extends ScrollPaneGuiImpl
{     
   /** Max workspace size */
   public static Dimension maxSize;
   
   /** Content panel */
   private ScrollableContainer contentPane;

   /**
    * Constructor.
    * 
    * @param   id
    *          The widget's ID.
    * @param   bars
    *          Container scroll bars.
    */
   public WindowWorkSpace(WidgetId id, Bars bars)
   {
      super(id, new ScrollableContainer(WidgetId.nextID()));
      this.config().sysbgcolor = SysColor.COLOR_3DSHADOW;
      viewport().setExtent(width(), height());
      // scroll bars
      this.setScrollBars(bars);
      // content pane
      contentPane = (ScrollableContainer) getChild();
      contentPane.config().sysbgcolor = SysColor.COLOR_3DSHADOW;
      contentPane.setInheritHeight(true);
      contentPane.setInheritWidth(true);
      int msgLines = ThinClient.getInstance().getMessageLines();
      maxSize = new Dimension(GuiConstants.DEF_COLUMNS, GuiConstants.DEF_ROWS - msgLines);   
      }
   
   /**
    * Add widget to container.
    *
    * @param   widget
    *          Widget to add.
    *
    * @return  <code>this</code> for fluent syntax support.
    */
   @Override
   public Container<GuiOutputManager> add(Widget<GuiOutputManager> widget)
   {
      if (contentPane == null)
      {
         return super.add(widget);
      }
      return contentPane.add(widget);
   }
   
   /**
    * Detach this widget from this container.  The widget will not be destroyed.
    * 
    * @param   widget
    *          Widget to detach.
    */
   @Override
   public void detach(Widget<GuiOutputManager> widget)
   {
      contentPane.detach(widget);
   }

   /**
    * Get workspace content pane.
    * 
    * @return  content pane.
    */
   public Container<GuiOutputManager> getContentPane() 
   {
      return contentPane;
   }
}
