/*
** Module   : PaintStructure.java
** Abstract : A structure used to store paint parameters.
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 MAG 20140508 First version.
** 002 MAG 20140912 Add fillPoly parameters.
** 003 EVL 20141116 Adding round rectangles draw and fill.
** 004 EVL 20141125 Adding dotted line draw capability.
** 005 EVL 20150203 Adding image offset options.
** 006 EVL 20150218 Adding support TRANSPARENT, STRETCH-TO-FIT, RETAIN-SHAPE and
**                  CONVERT-3D-COLORS options to image drawing.
** 007 CA  20150408 Added window title.
** 008 CA  20150507 Added flag to center text vertically, when drawing.
** 009 GES 20150417 Removed all Swing-specific data structures/imports. Moved the class to a
**                  generic location that is naturally shared across all GUI drivers.
**/

package com.goldencode.p2j.ui.client.gui.driver;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.client.*;

/**
 * A structure used to store paint parameters. Depending on paint operation different fields are
 * used.
 */
public class PaintStructure<F, I>
{
   /** Paint operation */
   public PaintPrimitives id;
   
   /** X parameter */
   public int x;
   
   /** Y parameter */
   public int y;
   
   /** Width parameter */
   public int width;
   
   /** Height parameter */
   public int height;
   
   /** X offset to start drawing image. */
   public int xOffset;
   
   /** Y offset to start drawing image. */
   public int yOffset;
   
   /** Transparency image flag. */
   public boolean transparent;
   
   /** Fit image to surrounding area flag. */
   public boolean stretchToFit;
   
   /** Keep image aspect ratio when fitting image to area flag. */
   public boolean retainShape;
   
   /** Replace certain colors with predefined system wide 3D colors flag. */
   public boolean convert3D;
   
   /** Diameter of the arc at the four corner. */
   public int arcDiameter;
   
   /** Polygon X coordinates */
   public int[] xPoints;
   
   /** Polygon Y coordinates */
   public int[] yPoints;
   
   /** Polygon number of coordinates */
   public int nPoints;
      
   /** Raised parameter for 3D operations */
   public boolean raised;
   
   /** Font parameter */
   public FontDetails<F> font;
   
   /** Font style constant. */
   public FontStyle style;
   
   /** Color parameter */
   public ColorRgb color;
   
   /** Text to draw */
   public String text;
   
   /** Image to draw */
   public ImageWrapper<I> img;

   /** Pattern to draw the lines. */
   public LineStroke stroke;
   
   /** Optional width for the stroke. */
   public float strokeWidth;

   /** The OS window's title. */
   public String title;
   
   /** Flag indicating if the text needs to be centered vertically. */
   public boolean centered;

   /**
    * Constructor.
    * 
    * @param   id
    *          Paint operation id.
    */
   public PaintStructure(PaintPrimitives id)
   {
      this.id = id;
   }
}
